%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Script to preprocess a VTC file in Matlab
% For BrainVoyager QX 2.2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

bvqx = actxserver('BrainVoyagerQX.BrainVoyagerQXScriptAccess.1');
bvqx.ShowLogTab;
bvqx.PrintToLog('Preprocessing VTC files from Matlab...');

doc = bvqx.ActiveDocument;
if (isempty(doc)) 
    [FileName,PathName] = uigetfile('*.vmr', 'Please select the VMR file ');
    vmr = bvqx.OpenDocument([PathName FileName]);
end
vtc = vmr.FileNameOfCurrentVTC;
if (isempty(vtc)) 
    [FileName,PathName] = uigetfile('*.vtc', 'Please select the VTC file ');
    vmr.LinkVTC([PathName FileName]);
end

% now smooth VTC with a large kernel of 10 mm:
vmr.SpatialGaussianSmoothing(10, 'mm' );    % FWHM value and unit ('mm' or 'vx')
bvqx.PrintToLog(['Name of spatially smoothed VTC file: ' vmr.FileNameOfCurrentVTC]);

% now we could do a linear trend removal (see code in comments)
% since high-pass temporal filter (see below) includes LTR, we skip this here
% vmr.LinearTrendRemoval();    % FWHM value and unit ('mm' or 'vx')
% bvqx.PrintToLog(['Name of VTC file without linear trends: ' docVMR.FileNameOfCurrentVTC]);

% now perform temporal high-pass filter
vmr.TemporalHighPassFilter(3, 'cycles');    % HP value and unit ('cycles' or 'Hz')
bvqx.PrintToLog(['Name of VTC file without linear trends: ' vmr.FileNameOfCurrentVTC]);

% now perform Gaussian temporal smoothing
vmr.TemporalGaussianSmoothing(3, 'dps');    % FWHM value and unit ('d' or 'dps' (data points) or 's' or 'secs' (seconds))
bvqx.MessageBox(['Name of temporally smoothed VTC file: ' vmr.FileNameOfCurrentVTC]);
disp('Finished preprocessing VTC file.')
